%  Copyright 2013 Kwang In Kim, Max-Planck-Institut for Informatics
%  Please refer to license.txt for sanctioned usage.
%
function GLap = BuildGLapFromT(TMat, NFlag)
%%% Build a graph Laplacian from the positive entries of T.
%%% If NFlag==1, the graph Laplacian is normalized; default: unnormalized.

[SizeTR,SizeTC] = size(TMat);

SimMat = sparse(SizeTR,SizeTR);
PosIdx = find(TMat>0);
SimMat(PosIdx) = TMat(PosIdx);
D = diag(sum(SimMat));
GLap = D-SimMat;
if nargin>=2 && NFlag == 1
    for i=1:SizeTR
        if D(i,i)~=0
            D(i,i) = 1/sqrt(D(i,i));
        end
    end
    GLap = D'*GLap*D;
    GLap = (GLap'+GLap)/2;
end
