%  Copyright 2013 Kwang In Kim, Max-Planck-Institut for Informatics
%  Please refer to license.txt for sanctioned usage.
%
function FMatOpt = LinkPrediction(TMat, Param, MaxSim)
%%% TMat: label matrix; positive entries: match score, negative entries: match failed (typically assigned with an constant, e.g., -1), zero entries: no information available yet for the corresponding pairs (no match yet performed). If the match algorithm does not produce continuous values but a binary decision (`successful' or `fail'), one could assign +1 for the corresponding entries of T. Of course, continuous values are more informative and would lead to better match predictions.

%%% Param.Lambda: Regularization parameter.
%%% Param.NFlag: 1 if the regularizer should normalized, and 0 otherwise.

%%% MaxSim: maximum possible match score to be assigned to self matches:
%%% It is assumed that an image always matches itself and the
%%% corresponding match score is maximum; default: 1

if nargin < 3
    MaxSim = 1;
end

[SizeTR,SizeTC] = size(TMat);
if SizeTR~=SizeTC
    error('T should be a square matrix.');
end

%%% Make sure that the label matrix T symmetric and its diagonal elements are one
    TMat = max(TMat,TMat');
    for i=1:SizeTR
        TMat(i,i) = MaxSim;
    end
%%% Make sure that the label matrix T symmetric and its diagonal elements are one

GLap = BuildGLapFromT(TMat, Param.NFlag);

A = Param.Lambda*GLap;
for i=1:SizeTR
    A(i,i) = A(i,i)+1;
end
FMatOpt = A\TMat;
